@@ -19,7 +19,7 @@ ALL_CIPHERS = (
     'AES-256-CTR', 'AES-256-CBC',
     'AES-192-CTR', 'AES-192-CBC',
     'AES-128-CTR', 'AES-128-CBC',
-    'CAMELLIA-256-CBC', 'CAMELLIA-128-CBC',
+    'CAMELLIA-256-CBC', 'CAMELLIA-192-CBC', 'CAMELLIA-128-CBC',
     '3DES-CBC', 'DES-CBC', 'RC4-40', 'RC4-128',
     'DES40-CBC', 'RC2-CBC', 'IDEA-CBC', 'SEED-CBC',
     'AES-256-CFB', 'AES-192-CFB', 'AES-128-CFB',
@@ -52,8 +52,7 @@ ALL_HASHES = (
 
 # we disable curves <= 256 bits by default in Fedora
 EXPERIMENTAL_GROUPS = (
-    'KYBER768',
-    'X25519-KYBER768', 'P256-KYBER768',
+    # 'KYBER768', 'X25519-KYBER768', 'P256-KYBER768',  # no KYBER, only ML-KEM
     'MLKEM512',
     'P256-MLKEM512', 'X25519-MLKEM512',
     'MLKEM768',
@@ -80,22 +79,24 @@ EXPERIMENTAL_SIGN = (
     'MLDSA65-P256', 'MLDSA65-BP256', 'MLDSA65-ED25519',
     'MLDSA87',
     'P521-MLDSA87', 'MLDSA87-P384', 'MLDSA87-BP384', 'MLDSA87-ED448',
-    'FALCON512',
-    'P256-FALCON512', 'RSA3072-FALCON512',
-    'FALCONPADDED512',
-    'P256-FALCONPADDED512', 'RSA3072-FALCONPADDED512',
-    'FALCON1024',
-    'P521-FALCON1024',
-    'FALCONPADDED1024',
-    'P521-FALCONPADDED1024',
-    'SPHINCSSHA2128FSIMPLE',
-    'P256-SPHINCSSHA2128FSIMPLE', 'RSA3072-SPHINCSSHA2128FSIMPLE',
-    'SPHINCSSHA2128SSIMPLE',
-    'P256-SPHINCSSHA2128SSIMPLE', 'RSA3072-SPHINCSSHA2128SSIMPLE',
-    'SPHINCSSHA2192FSIMPLE',
-    'P384-SPHINCSSHA2192FSIMPLE',
-    'SPHINCSSHAKE128FSIMPLE',
-    'P256-SPHINCSSHAKE128FSIMPLE', 'RSA3072-SPHINCSSHAKE128FSIMPLE',
+    # no FALCON, only FN-DSA
+    # 'FALCON512',
+    # 'P256-FALCON512', 'RSA3072-FALCON512',
+    # 'FALCONPADDED512',
+    # 'P256-FALCONPADDED512', 'RSA3072-FALCONPADDED512',
+    # 'FALCON1024',
+    # 'P521-FALCON1024',
+    # 'FALCONPADDED1024',
+    # 'P521-FALCONPADDED1024',
+    # no SPHINCS, only SLH-DSA
+    # 'SPHINCSSHA2128FSIMPLE',
+    # 'P256-SPHINCSSHA2128FSIMPLE', 'RSA3072-SPHINCSSHA2128FSIMPLE',
+    # 'SPHINCSSHA2128SSIMPLE',
+    # 'P256-SPHINCSSHA2128SSIMPLE', 'RSA3072-SPHINCSSHA2128SSIMPLE',
+    # 'SPHINCSSHA2192FSIMPLE',
+    # 'P384-SPHINCSSHA2192FSIMPLE',
+    # 'SPHINCSSHAKE128FSIMPLE',
+    # 'P256-SPHINCSSHAKE128FSIMPLE', 'RSA3072-SPHINCSSHAKE128FSIMPLE',
 )
 ALL_SIGN = (
     'RSA-MD5', 'RSA-SHA1', 'DSA-SHA1', 'ECDSA-SHA1',
